@@ -8,7 +8,8 @@ See "pytest_plugins in non-top-level conftest files" in
 https://docs.pytest.org/en/stable/deprecations.html
 """
 
-import pathlib
+from __future__ import annotations
+
 import shutil
 import typing as t
 
@@ -21,13 +22,16 @@ from libtmux.server import Server
 from libtmux.session import Session
 from libtmux.window import Window
 
+if t.TYPE_CHECKING:
+    import pathlib
+
 pytest_plugins = ["pytester"]
 
 
 @pytest.fixture(autouse=True)
 def add_doctest_fixtures(
     request: pytest.FixtureRequest,
-    doctest_namespace: t.Dict[str, t.Any],
+    doctest_namespace: dict[str, t.Any],
 ) -> None:
     """Configure doctest fixtures for pytest-doctest."""
     if isinstance(request._pyfuncitem, DoctestItem) and shutil.which("tmux"):
