@@ -1,5 +1,7 @@
 """Test for libtmux Session object."""
 
+from __future__ import annotations
+
 import logging
 import shutil
 import typing as t
@@ -10,11 +12,13 @@ from libtmux import exc
 from libtmux.common import has_gte_version, has_lt_version
 from libtmux.constants import WindowDirection
 from libtmux.pane import Pane
-from libtmux.server import Server
 from libtmux.session import Session
 from libtmux.test import TEST_SESSION_PREFIX, namer
 from libtmux.window import Window
 
+if t.TYPE_CHECKING:
+    from libtmux.server import Server
+
 logger = logging.getLogger(__name__)
 
 
@@ -322,9 +326,9 @@ def test_new_window_with_environment_logs_warning_for_old_tmux(
         environment={"ENV_VAR": "window"},
     )
 
-    assert any(
-        "Environment flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Environment flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
 
 
 @pytest.mark.skipif(
@@ -374,6 +378,6 @@ def test_session_new_window_with_direction_logs_warning_for_old_tmux(
         direction=WindowDirection.After,
     )
 
-    assert any(
-        "Direction flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Direction flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
